scoretools.get_one_indexed_measure_number_in_expr
=================================================

.. autofunction:: abjad.tools.scoretools.get_one_indexed_measure_number_in_expr.get_one_indexed_measure_number_in_expr
